@@ -4,6 +4,7 @@ NULL
 setOldClass("sessionInfo")
 
 ##' @export
+##' @rdname SwitchrParam
 setClass("SwitchrParam", representation(logfun = "function", shell_init = "character",
                                         archive_timing="numeric", archive_retries="numeric",
                                         dl_method = "character",
@@ -62,6 +63,7 @@ RepoSubset = function(repos, pkgs, default_name) {
 }
 
 ##' PkgSource
+##' 
 ##' An object representing the source location of a package. This is a virtual
 ##' used exlusively through its subclasses, which are used to differentiate the
 ##' different types of package source locations.
@@ -114,6 +116,10 @@ setAs("GitSource", "SVNSource",
 
 
 
+ensureCRANmirror = function(ind=1L) {
+    if(!interactive() && any(getOption("repos") == "@CRAN@"))
+        chooseCRANmirror(ind=ind)
+}
 
 
 
@@ -138,6 +144,7 @@ setClass("PkgManifest", representation( manifest = "data.frame",
 ##' @aliases PkgManifest-class
 ##' @importFrom utils read.table
 PkgManifest = function(manifest = ManifestRow(...), dep_repos = defaultRepos(), ..., dl_method){
+    ensureCRANmirror(1L)
     if(is.character(manifest)) {
         if(url.exists(manifest)) {
             fil = tempfile()
@@ -215,6 +222,7 @@ setClass("parsedSessionInfo", representation(version = "character",
 
 
 ##' LibraryProfile (experimental)
+##' 
 ##' Currently unused/under heavy development.
 ##'
 ##' An object
